cpuidle menu: remove 8 bytes of padding on 64 bit builds

Reorder struct menu_device to remove 8 bytes of padding on 64 bit builds.
Size drops from 136 to 128 bytes, so possibly needing one fewer cache
lines.

Signed-off-by: Richard Kennedy <[email protected]>
Cc: Arjan van de Ven <[email protected]>
Signed-off-by: Andrew Morton <[email protected]>
Signed-off-by: Linus Torvalds <[email protected]>
This commit is contained in:
Richard Kennedy 2010-03-05 13:42:30 -08:00 • committed by Linus Torvalds
commit 56e6943b41

View file

@ -100,8 +100,8 @@ struct menu_device {
int needs_update;
unsigned int expected_us;
u64 predicted_us;
unsigned int measured_us;
u64 predicted_us;
unsigned int exit_us;
unsigned int bucket;
u64 correction_factor[BUCKETS];